@@ -100,11 +100,11 @@ struct _GstDiscovererInfo {
   GstTagList *tags;
   GstToc *toc;
   gboolean seekable;
+  GPtrArray *missing_elements_details;
 
   gpointer _gst_reserved[GST_PADDING];
 };
 
 /* missing-plugins.c */
-
+G_GNUC_INTERNAL
 GstCaps *copy_and_clean_caps (const GstCaps * caps);
-gboolean has_single_media_type (const GstCaps * caps);
